pub struct Options {
pub chars_as_u16: bool,
pub bigdecimal_binary: bool,
pub json_binary: bool,
}Fields
chars_as_u16: boolThe Scala version of desert represented characters as 16-bit Unicode characters. Enabling this flag makes desert-rust compatible with that encoding, but serialization will fail on characters not fitting into this encoding.
bigdecimal_binary: boolEncode BigDecimal values as binary (scale, BigInt) pairs instead of decimal strings.
json_binary: boolEncode serde_json::Value values as typed binary trees instead of JSON text bytes.
Implementations
Sourceimpl Options
impl Options
Sourcepub fn scala_compatible() -> Options
pub fn scala_compatible() -> Options
Settings for binary compatibility with the Scala version of desert
pub fn with_binary_bigdecimal(self) -> Options
pub fn with_binary_json(self) -> Options