Module spawn

Module spawn 

Functions

spawn
Spawn a future on the tokio runtime with test context propagation. If the spawned task panics and the test uses DetachedPanicPolicy::FailTest (default), the panic will be reported as a test failure after the test body completes.
spawn_thread
Spawn a thread with test context propagation. If the spawned thread panics and the test uses DetachedPanicPolicy::FailTest (default), the panic will be reported as a test failure after the test body completes.