pub struct CloneableCodec {
pub to_wire: Arc<dyn Fn(Arc<dyn Any + Send + Sync>) -> Vec<u8> + Send + Sync>,
pub from_wire_bytes: Arc<dyn Fn(&[u8]) -> Arc<dyn Any + Send + Sync> + Send + Sync>,
}Expand description
Function-pointer wrappers used by Cloneable deps to convert the constructed value into wire bytes on the parent, and to deserialize those bytes into a typed value on the worker.
Fields
to_wire: Arc<dyn Fn(Arc<dyn Any + Send + Sync>) -> Vec<u8> + Send + Sync>Parent-side: to_wire. Receives the dependency value as Arc<dyn Any>,
returns the encoded wire bytes.
from_wire_bytes: Arc<dyn Fn(&[u8]) -> Arc<dyn Any + Send + Sync> + Send + Sync>Worker-side: deserialize wire bytes into the boxed Wire payload that
is then fed to the WorkerReconstructor.