spawn

Function spawn 

pub fn spawn<F>(future: F) -> JoinHandle<<F as Future>::Output>
where F: Future + Send + 'static, <F as Future>::Output: Send + 'static,
Spawn a future on the tokio runtime with test context propagation. If the spawned task panics and the test uses DetachedPanicPolicy::FailTest (default), the panic will be reported as a test failure after the test body completes.