pub fn spawn_thread<F, T>(f: F) -> JoinHandle<T>Expand description
Spawn a thread with test context propagation.
If the spawned thread panics and the test uses DetachedPanicPolicy::FailTest (default),
the panic will be reported as a test failure after the test body completes.