pub struct Options {
pub chars_as_u16: bool,
}Fields
chars_as_u16: boolThe Scala version of desert represented characters as 16-bit Unicode characters. Enabling this flag makes desert-rust compatible with that encoding, but serialization will fail on characters not fitting into this encoding.
Implementations